CustomerService class

Inheritance

Constructors

CustomerService(dynamic baseUrl, Options baseOptions)

Properties

baseOptions Options
getter/setter pair
baseUrl String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deletex<T>(String path, {Map<String, String>? headers, Object? body}) Future<Response>
inherited
findCustomers(Options options) Future<ResponseListModel>
Find customers @returns customers
getx<T>(String path, {Map<String, String>? headers}) Future<Response>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postx<T>(String path, {Map<String, String>? headers, Object? body}) Future<Response>
inherited
putx<T>(String path, {Map<String, String>? headers, Object? body}) Future<Response>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited